<?php

namespace Drp\AdfsAuthentication\Exceptions;

class InvalidIdTokenException extends \Exception
{

    /**
     * @var int
     */
    protected $httpStatusCode;

    /**
     * @var string
     */
    protected $errorType;

    /**
     * @var null|string
     */
    protected $hint;

    /**
     * Throw a new exception.
     *
     * @param string $message Error message
     * @param int $code Error code
     * @param string $errorType Error type
     * @param int $httpStatusCode HTTP status code to send (default = 400)
     * @param null|string $hint A helper hint
     */
    public function __construct($message, $code, $errorType, $httpStatusCode = 400, $hint = null)
    {
        parent::__construct($message, $code);
        $this->httpStatusCode = $httpStatusCode;
        $this->errorType = $errorType;
        $this->hint = $hint;
    }

    /**
     * Unusable token received from ADFS Server
     *
     * @return static
     */
    public static function invalidToken()
    {
        return new static(
            'Invalid Token Received from Server. Aborting.',
            6,
            'invalid_token',
            500
        );
    }
}
